==> opennebula_4.5.80.orig.tar.gz: opennebula-4.5.80/include/RequestManagerProxy.h <==
/* -------------------------------------------------------------------------- */
/* Copyright 2002-2014, OpenNebula Project (OpenNebula.org), C12G Labs        */
/*                                                                            */
/* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
/* not use this file except in compliance with the License. You may obtain    */
/* a copy of the License at                                                   */
/*                                                                            */
/* http://www.apache.org/licenses/LICENSE-2.0                                 */
/*                                                                            */
/* Unless required by applicable law or agreed to in writing, software        */
/* distributed under the License is distributed on an "AS IS" BASIS,          */
/* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   */
/* See the License for the specific language governing permissions and        */
/* limitations under the License.                                             */
/* -------------------------------------------------------------------------- */

#ifndef REQUEST_MANAGER_PROXY_H_
#define REQUEST_MANAGER_PROXY_H_

#include "Request.h"
#include "Client.h"

using namespace std;

/* ------------------------------------------------------------------------- */
/* ------------------------------------------------------------------------- */

class RequestManagerProxy: public Request
{
public:
    RequestManagerProxy(string _method);

    ~RequestManagerProxy();

    void request_execute(xmlrpc_c::paramList const& _paramList,
                         RequestAttributes& att);

private:
    Client *  client;

    string    method;
};

#endif

==> opennebula_4.6.0.orig.tar.gz: opennebula-4.6.0/include/RequestManagerProxy.h <==
/* -------------------------------------------------------------------------- */
/* Copyright 2002-2014, OpenNebula Project (OpenNebula.org), C12G Labs        */
/*                                                                            */
/* Licensed under the Apache License, Version 2.0 (the "License"); you may    */
/* not use this file except in compliance with the License. You may obtain    */
/* a copy of the License at                                                   */
/*                                                                            */
/* http://www.apache.org/licenses/LICENSE-2.0                                 */
/*                                                                            */
/* Unless required by applicable law or agreed to in writing, software        */
/* distributed under the License is distributed on an "AS IS" BASIS,          */
/* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   */
/* See the License for the specific language governing permissions and        */
/* limitations under the License.                                             */
/* -------------------------------------------------------------------------- */

#ifndef REQUEST_MANAGER_PROXY_H_
#define REQUEST_MANAGER_PROXY_H_

#include "Request.h"
#include "Client.h"

using namespace std;

/* ------------------------------------------------------------------------- */
/* ------------------------------------------------------------------------- */

class RequestManagerProxy: public Request
{
public:
    RequestManagerProxy(string _method);

    ~RequestManagerProxy();

    void request_execute(xmlrpc_c::paramList const& _paramList,
                         RequestAttributes& att);

    void hide_argument(int arg);

private:
    Client *  client;

    string    method;

    int hidden_arg;

    void log_xmlrpc_param(
            const xmlrpc_c::value&  v,
            ostringstream&          oss,
            const int&              index);
};

#endif
